difconet.noise.inspection: PLOT ESTIMATED CORRELATION DISTRIBUTION AFTER ADDING NOISE
Description
Plots the estimated correlation distribution of a normal dataset after adding different levels of gaussian noise. It is used to estimate the level of noise needed to be added to a normal dataset to match the correlation distribution of a tumor dataset. This assumes that the correlation distribution of the tumor dataset is sharper around zero.
The normal dataset. Rows are genes and columns are samples.
tdata
The tumor dataset. Rows are genes and columns are samples. Rows of tumor and normal datasets should be the same.
sigma
Levels of gaussian noise to be added (at zero mean).
maxgenes
Number of genes used to estimate the correlation distribution. If the number of rows in normal/tumor datasets are larger than maxgenes, maxgenes random genes are used for the estimation.
corfunc
Correlation method used.
Value
Nothing.
Details
Plots the estimated density of correlation distributions of normal, tumor, and normal after adding sigma levels of noise.
References
Gonzalez-Valbuena and Trevino 2017 Metrics to Estimate Differential Co-Expression Networks Journal Pendingvolume 00--10